@@ -1,12 +1,14 @@
 ##' @rdname toVariable
 ##' @export
 setMethod("toVariable", "character", function (x, ...) {
-    return(list(values=x, type="text", ...))
+    return(structure(list(values=x, type="text", ...),
+        class="VariableDefinition"))
 })
 ##' @rdname toVariable
 ##' @export
 setMethod("toVariable", "numeric", function (x, ...) {
-    return(list(values=x, type="numeric", ...))
+    return(structure(list(values=x, type="numeric", ...),
+        class="VariableDefinition"))
 })
 ##' @rdname toVariable
 ##' @export
@@ -16,26 +18,35 @@ setMethod("toVariable", "factor", function (x, ...) {
     if (!is.null(max.categories) && nlevels > max.categories) {
         return(toVariable(as.character(x), ...))
     } 
-    out <- list(values=as.integer(x), type="categorical",
-        categories=categoriesFromLevels(levels(x)), ...)
-    return(NAToCategory(out))
+    out <- structure(list(values=as.integer(x), type="categorical",
+        categories=categoriesFromLevels(levels(x)), ...),
+        class="VariableDefinition")
+    return(NAToCategory(out, useNA="always"))
 })
 ##' @rdname toVariable
 ##' @export
 setMethod("toVariable", "Date", function (x, ...) {
-    return(list(values=as.character(x), type="datetime", resolution="D", ...))
+    return(structure(list(values=as.character(x), type="datetime",
+        resolution="D", ...),
+        class="VariableDefinition"))
 })
 # setMethod("toVariable", "POSIXt", function (x) {
 #     return(list(values=as.character(x), type="datetime", resolution="s", ...))
 # })
 
+##' @rdname toVariable
+##' @export
+setMethod("toVariable", "VariableDefinition", function (x, ...) {
+    return(updateList(x, list(...)))
+})
 ##' @rdname toVariable
 ##' @export
 setMethod("toVariable", "logical", function (x, ...) {
     ## Make it categorical
-    out <- list(values=2L-as.integer(x), type="categorical", 
+    out <- structure(list(values=2L-as.integer(x), type="categorical", 
         categories=categoriesFromLevels(c("True", "False")),
-        ...)
+        ...),
+        class="VariableDefinition")
     return(NAToCategory(out))
 })
 
@@ -45,8 +56,9 @@ categoriesFromLevels <- function (x) {
     }))
 }
 
-NAToCategory <- function (var.metadata) {
-    if (any(is.na(var.metadata$values))) {
+NAToCategory <- function (var.metadata, useNA=c("ifany", "always")) {
+    useNA <- match.arg(useNA)
+    if (useNA == "always" || any(is.na(var.metadata$values))) {
         var.metadata$values[is.na(var.metadata$values)] <- -1L
         var.metadata$categories[[length(var.metadata$categories)+1]] <- .no.data
     }
