@@ -8,7 +8,6 @@
 ##'
 ##' @param x an input
 ##' @param table For \code{\%in\%}. See \code{\link[base]{match}}
-##' @param mode For \code{as.vector}. Ignored.
 ##' @param resolution For \code{rollup}. Either \code{NULL} or a character in 
 ##' c("Y", "Q", "M", "W", "D", "h", "m", "s", "ms") indicating the unit of 
 ##' time at which a Datetime variable should be aggregated. If \code{NULL}, 
@@ -20,7 +19,7 @@
 ##' @name expressions
 NULL
 
-##' @rdname expressions
+##' @rdname variable-to-R
 ##' @export
 setMethod("as.vector", "CrunchExpr", function (x, mode) {
     payload <- list(command="select", variables=list(out=zcl(x)))
@@ -30,11 +29,16 @@ setMethod("as.vector", "CrunchExpr", function (x, mode) {
     # cat(toJSON(payload))
     out <- crPOST(paste0(x@dataset_url, "table/"), body=toJSON(payload))
     ## pass in the variable metadata to the column parser
-    variable <- as.variable(structure(list(body=out$metadata$out),
+    variable <- VariableEntity(structure(list(body=out$metadata$out),
         class="shoji"))
     return(columnParser(out$metadata$out$type, mode)(out$data$out, variable))
 })
 
+##' @rdname toVariable
+##' @export
+setMethod("toVariable", "CrunchExpr", function (x, ...) {
+    structure(list(expr=zcl(x), ...), class="VariableDefinition")
+})
 
 ## "Ops" for Crunch Variables
 ##
@@ -210,7 +214,7 @@ rollup <- function (x, resolution=rollupResolution(x)) {
 
 rollupResolution <- function (x) {
     if (is.Datetime(x)) {
-        return(x@body$view$rollup_resolution)
+        return(entity(x)@body$view$rollup_resolution)
     } else {
         return(NULL)
     }
