@@ -82,3 +82,40 @@ hiddenVariables <- function (dataset, key="name") {
     }
 }
 
+##' Delete Variables Within a Dataset
+##' @param dataset the Dataset to modify
+##' @param variables names or indices of variables to delete
+##' @param pattern optional regular expression to identify Variables to delete
+##' @param key the Variable attribute to \code{\link{grep}} with the
+##' \code{pattern}. Default is "alias"
+##' @param confirm logical: should the user be asked to confirm deletion. 
+##' Default is \code{TRUE} if in 
+##' an interactive session. You can avoid the confirmation prompt if you delete
+##' \code{with(\link{consent})}.
+##' @param ... optional additional arguments to \code{grep}
+##' @return (invisibly) \code{dataset} with the specified variables deleted
+##' @seealso \code{\link{hide}}
+##' @export
+deleteVariables <- function (dataset, variables=NULL, pattern=NULL, key=namekey(dataset), confirm=requireConsent(), ...) {
+    var.urls <- findVariableURLs(dataset, refs=variables, pattern=pattern, key=key, ...)
+    if (length(var.urls) == 1) {
+        varnames <- names(allVariables(dataset)[var.urls])
+        prompt <- paste0("Really delete ", dQuote(varnames), "?")
+    } else {
+        prompt <- paste0("Really delete these ", length(var.urls), 
+            " variables?")
+    }
+    if (confirm && !askForPermission(prompt)) {
+        halt("Must confirm deleting variable(s)")
+    }
+    out <- lapply(var.urls, function (x) try(crDELETE(x)))
+    ## Now, delete subvariables. When deleting an array, the DELETE request
+    ## returns the subvariable URLs as a response body
+    subvar.urls <- unlist(Filter(Negate(is.error), out))
+    out2 <- lapply(subvar.urls, function (x) try(crDELETE(x)))
+    invisible(refresh(dataset))
+}
+
+##' @rdname deleteVariables
+##' @export
+deleteVariable <- deleteVariables
\ No newline at end of file
