@@ -1,11 +1,3 @@
-init.CategoricalVariable <- function (.Object, ...) {
-    .Object <- callNextMethod()
-    .Object@body$categories <- Categories(data=.Object@body$categories)
-    return(.Object)
-}
-setMethod("initialize", "CategoricalVariable", init.CategoricalVariable)
-setMethod("initialize", "CategoricalArrayVariable", init.CategoricalVariable)
-
 setMethod("tuple", "CrunchVariable", function (x) x@tuple)
 setMethod("tuple<-", "CrunchVariable", function (x, value) {
     x@tuple <- value
@@ -55,53 +47,17 @@ is.Array <- function (x) inherits(x, "CategoricalArrayVariable")
 ##' @rdname crunch-is
 ##' @export
 is.CategoricalArray <- is.CA
-    
-as.variable <- function (x, subtype=NULL, tuple=VariableTuple()) {
-    x <- CrunchVariable(x)
-    if (is.variable(x)) {
-        x <- subclassVariable(x, to=subtype)
-        tuple(x) <- tuple
-    }
-    ## For the jsonlite no-simplify deserializer
-    if ("subvariables" %in% names(x@body)) {
-        x@body[["subvariables"]] <- absoluteURL(unlist(x@body[["subvariables"]]), self(x))
-    }
-    return(x)
-}
+
+##' @rdname self
+##' @export
+setMethod("self", "CrunchVariable", function (x) tuple(x)@entity_url)
 
 ##' @rdname refresh
 ##' @export
 setMethod("refresh", "CrunchVariable", function (x) {
-    tup <- refresh(tuple(x))
-    out <- as.variable(crGET(self(x)), tuple=tup)
-    activeFilter(out) <- activeFilter(x)
-    return(out)
+    return(CrunchVariable(refresh(tuple(x)), filter=activeFilter(x)))
 })
 
-as.Numeric <- function (x) as.variable(x, "numeric")
-as.Categorical <- function (x) as.variable(x, "categorical")
-as.Text <- function (x) as.variable(x, "text")
-
-subclassVariable <- function (x, to=NULL) {
-    if (is.null(to)) to <- type(x)
-    Constructor <- pickSubclassConstructor(to)
-    return(Constructor(x))
-}
-
-pickSubclassConstructor <- function (x=NULL) {
-    constructors <- list(
-            categorical=CategoricalVariable,
-            numeric=NumericVariable,
-            text=TextVariable,
-            datetime=DatetimeVariable,
-            multiple_response=MultipleResponseVariable,
-            categorical_array=CategoricalArrayVariable
-        )
-    if (!is.null(x)) x <- constructors[[x]]
-    if (is.null(x)) x <- CrunchVariable
-    return(x)
-}
-
 ##' @rdname describe
 ##' @export
 setMethod("name", "CrunchVariable", function (x) tuple(x)$name)
@@ -138,26 +94,34 @@ NULL
 setMethod("categories", "CrunchVariable", function (x) NULL)
 ##' @rdname var-categories
 ##' @export
-setMethod("categories", "CategoricalVariable", function (x) x@body$categories)
+setMethod("categories", "CategoricalVariable", 
+    function (x) categories(entity(x)))
 ##' @rdname var-categories
 ##' @export
 setMethod("categories", "CategoricalArrayVariable",
-    function (x) x@body$categories)
+    function (x) categories(entity(x)))
+
+##' @rdname var-categories
+##' @export
+setMethod("categories", "VariableEntity", 
+    function (x) Categories(data=x@body$categories))
 
 ##' @rdname var-categories
 ##' @export
 setMethod("categories<-", c("CategoricalVariable", "Categories"), 
     function (x, value) {
         dropCache(absoluteURL("../../cube/", self(x)))
-        return(setCrunchSlot(x, "categories", value))
+        ent <- setEntitySlot(entity(x), "categories", value)
+        return(x)
     })
 ##' @rdname var-categories
 ##' @export
 setMethod("categories<-", c("CategoricalArrayVariable", "Categories"), 
     function (x, value) {
         dropCache(absoluteURL("../../cube/", self(x)))
-        lapply(tuple(x)$subvariables, dropCache) ## Subvariables will update too
-        return(setCrunchSlot(x, "categories", value))
+        lapply(subvariables(tuple(x)), dropCache) ## Subvariables will update too
+        ent <- setEntitySlot(entity(x), "categories", value)
+        return(x)
     })
 ##' @rdname var-categories
 ##' @export
@@ -208,7 +172,11 @@ setMethod("categories<-", c("CrunchVariable", "ANY"),
         halt("category assignment not defined for ", class(x))
     })
 
-setMethod("datasetReference", "CrunchVariable", function (x) x@urls$dataset_url)
+setMethod("datasetReference", "CrunchVariable", function (x) {
+    # x@urls$dataset_url
+    ## Not HATEOAS
+    absoluteURL("../../", self(x))
+})
 setMethod("datasetReference", "ANY", function (x) NULL)
 
 ##' Split an array or multiple-response variable into its CategoricalVariables
@@ -228,11 +196,16 @@ unbind <- function (x) {
     invisible(out)
 }
 
+##' @rdname delete
+##' @export
+setMethod("delete", "CrunchVariable", 
+    function (x, ...) invisible(crDELETE(self(x))))
+
 ##' @rdname delete
 ##' @export
 setMethod("delete", "CategoricalArrayVariable", function (x, ...) {
     u <- self(x)
-    subvars <- x@body$subvariables
+    subvars <- subvariables(tuple(x))
     out <- crDELETE(u)
     lapply(subvars, crDELETE)
     dropCache(absoluteURL("../", u))
