@@ -77,7 +77,7 @@ if (run.integration.tests) {
                     expect_identical(dim(out), c(nrow(df)*2L, ncol(df)))
                     expect_identical(getNrow(out), nrow(df)*2L)
                     expect_identical(nrow(out), length(as.vector(out$v3)))
-                    expect_identical(categories(out$v4)[1:2], cats)
+                    expect_identical(categories(out$v4), cats)
                     expect_equivalent(as.vector(out$v3), rep(df$v3, 2))
                     expect_identical(as.vector(out$v3), c(v3.1, v3.2))
                 })
@@ -88,22 +88,14 @@ if (run.integration.tests) {
                     expect_true(is.dataset(out))
                     expect_identical(length(batches(out)), 2L)
                     expect_identical(dim(out), dim(df))
-                    expect_identical(categories(out$v4)[1:2], cats)
+                    expect_identical(categories(out$v4), cats)
                     expect_equivalent(as.vector(out$v3), df$v3)
                 })
             })
         })
         
-        try({
-            file1 <- newDatasetFromFile(testfile.csv, name=now())
-            file2 <- newDatasetFromFile(testfile.csv, name=now())
-        })
-        test_that("setup", {
-            expect_true(is.dataset(file1))
-            expect_true(is.dataset(file2))
-        })
-        with(test.dataset(file1), {
-            with(test.dataset(file2), {
+        with(test.dataset(newDatasetFromFile(testfile.csv, name=now()), "file1"), {
+            with(test.dataset(newDatasetFromFile(testfile.csv, name=now()), "file2"), {
                 v3.1 <- as.vector(file1$V3)
                 v3.2 <- as.vector(file2$V3)
                 test_that("our assumptions about these datasets from file", {
@@ -134,14 +126,6 @@ if (run.integration.tests) {
             cats <- categories(part1$v4)
             with(test.dataset(df[,1:3], "part2"), {
                 p1.batches <- batches(part1)
-                # test_that("if I insist on confirmation, it fails if there are conflicts", {
-                #     expect_true(inherits(p1.batches, "ShojiCatalog"))
-                #     expect_identical(length(p1.batches), 1L)
-                #     expect_error(suppressMessages(appendDataset(part1, part2,
-                #         confirm=TRUE)),
-                #         "Please manually resolve conflicts")
-                #     expect_identical(length(batches(part1)), 1L)
-                # })
                 out <- suppressMessages(try(appendDataset(part1, part2)))
                 test_that("append handles missing variables from each", {
                     expect_that(out, is_not_an_error())
@@ -151,7 +135,7 @@ if (run.integration.tests) {
                     expect_identical(ncol(out), length(allVariables(out)))
                     expect_true(setequal(names(out), paste0("v", 1:5)))
                     expect_identical(nrow(out), nrow(df) * 2L)
-                    expect_identical(categories(out$v4)[1:2], cats)
+                    expect_identical(categories(out$v4), cats)
                     expect_equivalent(as.vector(out$v3), rep(df$v3, 2))
                     expect_equivalent(as.vector(out$v1), 
                         c(rep(NA, nrow(df)), df$v1))
@@ -181,7 +165,7 @@ if (run.integration.tests) {
                     expect_identical(ncol(out), length(allVariables(out)))
                     expect_true(setequal(names(out), paste0("v", 1:5)))
                     expect_identical(nrow(out), nrow(df) * 2L)
-                    expect_identical(categories(out$v4)[1:2], cats)
+                    expect_identical(categories(out$v4), cats)
                     expect_equivalent(as.vector(out$v3), rep(df$v3, 2))
                     expect_equivalent(as.vector(out$v1), 
                         c(df$v1, rep(NA, nrow(df))))
@@ -262,13 +246,13 @@ if (run.integration.tests) {
                 test_that("Setup", {
                     expect_identical(as.character(as.vector(part1$C)),
                         c("B", "C", "A", "E", "D"))
-                    c1 <- categories(part1$C)
+                    c1 <- na.omit(categories(part1$C))
                     expect_identical(names(c1), lets)
                     expect_equivalent(values(c1), 1:5)
                     expect_equivalent(ids(c1), 1:5)
                     expect_identical(as.character(as.vector(part2$C)),
                         c("D", "C", "E", "A", "B"))
-                    c2 <- categories(part2$C)
+                    c2 <- na.omit(categories(part2$C))
                     expect_identical(names(c2), rev(lets))
                     expect_equivalent(values(c2), 1:5)
                     expect_equivalent(ids(c2), 1:5)
@@ -277,7 +261,7 @@ if (run.integration.tests) {
                 test_that("Categories with different ids and values line up by name", {
                     expect_identical(as.character(as.vector(out$C)),
                         c("B", "C", "A", "E", "D", "D", "C", "E", "A", "B"))
-                    cout <- categories(out$C)
+                    cout <- na.omit(categories(out$C))
                     ## Order comes from the "part1" dataset
                     expect_identical(names(cout), lets)
                     expect_equivalent(values(cout), 1:5)
