@@ -1,19 +1,5 @@
 context("Variables")
 
-test_that("Subclass constructor selector", {
-    expect_equivalent(class(pickSubclassConstructor("numeric")), 
-        "classGeneratorFunction")
-    expect_identical(pickSubclassConstructor("numeric"), NumericVariable)
-    expect_identical(pickSubclassConstructor("categorical"),
-        CategoricalVariable)
-    expect_identical(pickSubclassConstructor("text"), TextVariable)
-    expect_identical(pickSubclassConstructor("datetime"), DatetimeVariable)
-    expect_identical(pickSubclassConstructor("multiple_response"),
-        MultipleResponseVariable)
-    expect_identical(pickSubclassConstructor(), CrunchVariable)
-    expect_identical(pickSubclassConstructor("foo"), CrunchVariable)
-})
-
 with(fake.HTTP, {
     ds <- loadDataset("test ds")
     
@@ -89,13 +75,6 @@ if (run.integration.tests) {
                     ))
                 ## TODO: add other types
             })
-            
-            test_that("can delete variables", {
-                expect_true("v1" %in% names(ds))
-                d <- try(delete(ds$v1))
-                expect_that(d, is_not_an_error())
-                expect_false("v1" %in% names(refresh(ds)))
-            })
         })
         
         with(test.dataset(df), {
