@@ -47,14 +47,19 @@ if (run.integration.tests) {
             test_that("Dataset imported correctly", {
                 validImport(ds)
             })
+            
+            ## Release and re-lease
+            .releaseDataset(ds)
+            ds <- refresh(ds)
+            
             test_that("There is an initial version", {
-                expect_identical(length(versions(ds)), 1L)
                 expect_identical(names(versions(ds)), "initial import")
+                expect_identical(length(versions(ds)), 1L)
             })
 
             ## Make changes:
             # 1. Edit variable metadata
-            names(categories(ds$v4)) <- c("d", "e")
+            names(categories(ds$v4))[1:2] <- c("d", "e")
             name(ds$v2) <- "Variable Two"
             description(ds$v3) <- "The third variable in the dataset"
             
@@ -68,20 +73,41 @@ if (run.integration.tests) {
             # 4. Derive variable
             ds$v7 <- ds$v3 - 6
             
+            # 5. Add non-derived variable
+            ds$v8 <- rep(1:5, 4)
+            
             ## Assert those things
             test_that("The edits are made", {
-                expect_identical(names(categories(ds$v4)),
+                expect_identical(names(na.omit(categories(ds$v4))),
                     c("d", "e"))
                 expect_identical(name(ds$v2), "Variable Two")
                 expect_identical(description(ds$v3),
                     "The third variable in the dataset")
                 expect_identical(description(ds), "A dataset for testing")
                 expect_identical(as.vector(ds$v7), df$v3 - 6)
+                expect_equivalent(as.vector(ds$v8), rep(1:5, 4))
                 expect_identical(aliases(variables(ds)), 
-                    paste0("v", c(2,4,6,1,3,5,7)))
+                    paste0("v", c(2,4,6,1,3,5,7,8)))
+            })
+            
+            ## Release and re-lease
+            .releaseDataset(ds)
+            ds <- refresh(ds)
+            
+            ## Assert those things again
+            test_that("The edits made are still there after releasing", {
+                expect_identical(names(na.omit(categories(ds$v4))),
+                    c("d", "e"))
+                expect_identical(name(ds$v2), "Variable Two")
+                expect_identical(description(ds$v3),
+                    "The third variable in the dataset")
+                expect_identical(description(ds), "A dataset for testing")
+                expect_identical(as.vector(ds$v7), df$v3 - 6)
+                expect_equivalent(as.vector(ds$v8), rep(1:5, 4))
+                expect_identical(aliases(variables(ds)), 
+                    paste0("v", c(2,4,6,1,3,5,7,8)))
             })
             
-            # print(versions(ds))
             ## Save a version
             try(saveVersion(ds, "My changes"))
             test_that("There are now two versions", {
@@ -89,20 +115,38 @@ if (run.integration.tests) {
                 expect_identical(names(versions(ds))[1], "My changes")
             })
             
+            ## Release and re-lease
+            .releaseDataset(ds)
+            ds <- refresh(ds)
+            
             ## Revert to the first version
-            # ds <- try(restoreVersion(ds, "initial import"))
-            ## ^ fails occasionally bc of https://www.pivotaltracker.com/story/show/98580938
-            ds <- try(restoreVersion(ds, 2))
+            ds <- try(restoreVersion(ds, "initial import"))
             test_that("Restoring restored correctly", {
                 expect_identical(length(versions(ds)), 1L)
                 validImport(ds)
             })
+            
+            ## Release and re-lease
+            .releaseDataset(ds)
+            ds <- refresh(ds)
+            
             test_that("Added variables are really removed by rolling back", {
                 ## This was user-reported: Order was reverted but derived 
                 ## variables persisted, and by assigning an empty order, you can
                 ## recover them.
                 ordering(ds) <- VariableOrder()
-                expect_identical(names(ds), names(df))
+                expect_true(setequal(names(ds), names(df)))
+            })
+            
+            test_that("And now we can add variables again that we added and reverted", {
+                expect_true(is.null(ds$v7))
+                ## This would error if "v7" were still lurking somewhere
+                ds$v7 <- ds$v3 - 7
+                expect_identical(as.vector(ds$v7), df$v3 - 7)
+                
+                expect_true(is.null(ds$v8))
+                ds$v8 <- rep(6:10, 4)
+                expect_equivalent(as.vector(ds$v8), rep(6:10, 4))
             })
         })
     })
